==> qmmp_0.7.6.orig.tar.gz: qmmp-0.7.6/src/app/translations/qmmp_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Skip forward in playlist</source>
        <translation>Naar voren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Skip backwards in playlist</source>
        <translation>Naar achteren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Start playing current song</source>
        <translation>Begin met afspelen van huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Niet de afspeellijst leeghalen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Pause current song</source>
        <translation>Pauzeer huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="66"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pauzeer als er wordt gespeeld, anders spelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="67"/>
        <source>Stop current song</source>
        <translation>Stop huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="68"/>
        <source>Display Jump to File dialog</source>
        <translation>Weergeef bestandskeuze venster</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="69"/>
        <source>Quit application</source>
        <translation>Sluit applicatie</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="70"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Verander afspeelvolume (voorbeeld: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Show/hide application</source>
        <translation>Toon/verberg programma</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Display Add File dialog</source>
        <translation>Toon venster om bestanden toe te voegen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Display Add Directory dialog</source>
        <translation>Toon venster om mappen toe te voegen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="286"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Gebruik: qmmp [opties] [bestanden]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="287"/>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="291"/>
        <source>Don&apos;t start the application</source>
        <translation>Niet de applicatie starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="293"/>
        <source>Print version number and exit</source>
        <translation>Print versienummer en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="294"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Ideëen, patches, foutrapporten zenden naar forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="299"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="300"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Gecompileerd met QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="301"/>
        <source>Using Qt version: %1</source>
        <translation>Gebruikt QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="292"/>
        <source>Display this text and exit</source>
        <translation>Toon deze tekst en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="83"/>
        <source>Unknown command</source>
        <translation>Onbekend commando</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/app/translations/qmmp_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Naar voren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Naar achteren schuiven in afspeellijst</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Begin met afspelen van huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Niet de afspeellijst leeghalen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pauzeer huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pauzeer als er wordt gespeeld, anders spelen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Stop huidig nummer</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Weergeef bestandskeuze venster</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Sluit applicatie</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Verander afspeelvolume (voorbeeld: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Toon/verberg programma</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Toon venster om bestanden toe te voegen</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Toon venster om mappen toe te voegen</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="315"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Gebruik: qmmp [opties] [bestanden]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="316"/>
        <source>Options:</source>
        <translation>Opties:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="320"/>
        <source>Don&apos;t start the application</source>
        <translation>Niet de applicatie starten</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="322"/>
        <source>Print version number and exit</source>
        <translation>Print versienummer en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="323"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Ideëen, patches, foutrapporten zenden naar forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="326"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="339"/>
        <source>QMMP version: %1</source>
        <translation>QMMP versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="340"/>
        <source>Compiled with Qt version: %1</source>
        <translation>Gecompileerd met QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="341"/>
        <source>Using Qt version: %1</source>
        <translation>Gebruikt QT versie: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="344"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="321"/>
        <source>Display this text and exit</source>
        <translation>Toon deze tekst en sluit</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="88"/>
        <source>Unknown command</source>
        <translation>Onbekend commando</translation>
    </message>
</context>
</TS>
